/*
 * BRLTTY - A background process providing access to the console screen (when in
 *          text mode) for a blind person using a refreshable braille display.
 *
 * Copyright (C) 1995-2022 by The BRLTTY Developers.
 *
 * BRLTTY comes with ABSOLUTELY NO WARRANTY.
 *
 * This is free software, placed under the terms of the
 * GNU Lesser General Public License, as published by the Free Software
 * Foundation; either version 2.1 of the License, or (at your option) any
 * later version. Please see the file LICENSE-LGPL for details.
 *
 * Web Page: http://brltty.app/
 *
 * This software is maintained by Dave Mielke <dave@mielke.cc>.
 */

#ifndef BRLTTY_INCLUDED_ASYNC_WAIT
#define BRLTTY_INCLUDED_ASYNC_WAIT

#include "async_types_wait.h"

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

extern int asyncAwaitCondition (int timeout, AsyncConditionTester *testCondition, void *data);
extern void asyncWait (int duration);
extern void asyncWaitFor (AsyncConditionTester *testCondition, void *data);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* BRLTTY_INCLUDED_ASYNC_WAIT */
